@@ -22,27 +22,24 @@ implementations.
 =cut
 
 use strict;
-use Scalar::Util 'refaddr';
-use Params::Util '_INSTANCE',
-                 '_ARRAY';
+use Clone 0.30      ();
+use Scalar::Util    qw{refaddr};
+use Params::Util    qw{_INSTANCE _ARRAY};
+use List::Util      ();
+use PPI::Util       ();
 use PPI::Node       ();
-use Clone           ();
-use List::MoreUtils ();
-use overload 'bool' => sub () { 1 },
-             '""'   => 'content',
-             '=='   => '__equals',
-             '!='   => '__nequals',
-             'eq'   => '__eq',
-             'ne'   => '__ne';
+use PPI::Singletons '%_PARENT';
 
-use vars qw{$VERSION $errstr %_PARENT};
-BEGIN {
-	$VERSION = '1.203';
-	$errstr  = '';
+our $VERSION = '1.271'; # VERSION
 
-	# Master Child -> Parent index
-	%_PARENT = ();
-}
+our $errstr = "";
+
+use overload 'bool' => \&PPI::Util::TRUE;
+use overload '""'   => 'content';
+use overload '=='   => '__equals';
+use overload '!='   => '__nequals';
+use overload 'eq'   => '__eq';
+use overload 'ne'   => '__ne';
 
 
 
@@ -66,7 +63,7 @@ Returns true if the Element is significant, or false it not.
 =cut
 
 ### XS -> PPI/XS.xs:_PPI_Element__significant 0.845+
-sub significant { 1 }
+sub significant() { 1 }
 
 =pod
 
@@ -121,14 +118,14 @@ Returns the basic code as a string (excluding here-doc content).
 =cut
 
 ### XS -> PPI/XS.xs:_PPI_Element__content 0.900+
-sub content { '' }
+sub content() { '' }
 
 
 
 
 
 #####################################################################
-# Naigation Methods
+# Navigation Methods
 
 =pod
 
@@ -147,10 +144,48 @@ sub parent { $_PARENT{refaddr $_[0]} }
 
 =pod
 
+=head2 descendant_of $element
+
+Answers whether a C<PPI::Element> is contained within another one.
+
+C<PPI::Element>s are considered to be descendants of themselves.
+
+=cut
+
+sub descendant_of {
+	my $cursor = shift;
+	my $parent = shift or return undef;
+	while ( refaddr $cursor != refaddr $parent ) {
+		$cursor = $_PARENT{refaddr $cursor} or return '';
+	}
+	return 1;
+}
+
+=pod
+
+=head2 ancestor_of $element
+
+Answers whether a C<PPI::Element> is contains another one.
+
+C<PPI::Element>s are considered to be ancestors of themselves.
+
+=cut
+
+sub ancestor_of {
+	my $self   = shift;
+	my $cursor = shift or return undef;
+	while ( refaddr $cursor != refaddr $self ) {
+		$cursor = $_PARENT{refaddr $cursor} or return '';
+	}
+	return 1;
+}
+
+=pod
+
 =head2 statement
 
 For a C<PPI::Element> that is contained (at some depth) within a
-L<PPI::Statment>, the C<statement> method will return the first parent
+L<PPI::Statement>, the C<statement> method will return the first parent
 Statement object lexically 'above' the Element.
 
 Returns a L<PPI::Statement> object, which may be the same Element if the
@@ -194,6 +229,8 @@ sub top {
 
 =pod
 
+=head2 document
+
 For an Element that is contained within a L<PPI::Document> object,
 the C<document> method will return the top-level Document for the Element.
 
@@ -222,9 +259,9 @@ sub next_sibling {
 	my $parent   = $_PARENT{refaddr $self} or return '';
 	my $key      = refaddr $self;
 	my $elements = $parent->{children};
-	my $position = List::MoreUtils::firstidx {
-		refaddr $_ == $key
-		} @$elements;
+	my $position = List::Util::first {
+		refaddr $elements->[$_] == $key
+		} 0..$#$elements;
 	$elements->[$position + 1] || '';
 }
 
@@ -245,9 +282,9 @@ sub snext_sibling {
 	my $parent   = $_PARENT{refaddr $self} or return '';
 	my $key      = refaddr $self;
 	my $elements = $parent->{children};
-	my $position = List::MoreUtils::firstidx {
-		refaddr $_ == $key
-		} @$elements;
+	my $position = List::Util::first {
+		refaddr $elements->[$_] == $key
+		} 0..$#$elements;
 	while ( defined(my $it = $elements->[++$position]) ) {
 		return $it if $it->significant;
 	}
@@ -270,9 +307,9 @@ sub previous_sibling {
 	my $parent   = $_PARENT{refaddr $self} or return '';
 	my $key      = refaddr $self;
 	my $elements = $parent->{children};
-	my $position = List::MoreUtils::firstidx {
-		refaddr $_ == $key
-		} @$elements;
+	my $position = List::Util::first {
+		refaddr $elements->[$_] == $key
+		} 0..$#$elements;
 	$position and $elements->[$position - 1] or '';
 }
 
@@ -293,9 +330,9 @@ sub sprevious_sibling {
 	my $parent   = $_PARENT{refaddr $self} or return '';
 	my $key      = refaddr $self;
 	my $elements = $parent->{children};
-	my $position = List::MoreUtils::firstidx {
-		refaddr $_ == $key
-		} @$elements;
+	my $position = List::Util::first {
+		refaddr $elements->[$_] == $key
+		} 0..$#$elements;
 	while ( $position-- and defined(my $it = $elements->[$position]) ) {
 		return $it if $it->significant;
 	}
@@ -316,7 +353,7 @@ the same object.
 
 Returns a L<PPI::Token> object, or dies on error (which should be extremely
 rare and only occur if an illegal empty L<PPI::Statement> exists below the
-current Element somewhere.
+current Element somewhere.)
 
 =cut
 
@@ -344,7 +381,7 @@ the itself.
 
 Returns a L<PPI::Token> object, or dies on error (which should be extremely
 rare and only occur if an illegal empty L<PPI::Statement> exists below the
-current Element somewhere.
+current Element somewhere.)
 
 =cut
 
@@ -469,39 +506,7 @@ In future, this method may be enhanced to allow the insertion of multiple
 Elements, inline-parsed code strings or L<PPI::Document::Fragment> objects.
 
 Returns true if the Element was inserted, false if it can not be inserted,
-or C<undef> if you do not provide a L<PPI::Element> object as a parameter.
-
-=begin testing __insert_before 6
-
-my $Document = PPI::Document->new( \"print 'Hello World';" );
-isa_ok( $Document, 'PPI::Document' );
-my $semi = $Document->find_first('Token::Structure');
-isa_ok( $semi, 'PPI::Token::Structure' );
-is( $semi->content, ';', 'Got expected token' );
-my $foo = PPI::Token::Word->new('foo');
-isa_ok( $foo, 'PPI::Token::Word' );
-is( $foo->content, 'foo', 'Created Word token' );
-$semi->__insert_before( $foo );
-is( $Document->serialize, "print 'Hello World'foo;",
-	'__insert_before actually inserts' );
-
-=end testing
-
-=begin testing insert_before after __insert_before 6
-
-my $Document = PPI::Document->new( \"print 'Hello World';" );
-isa_ok( $Document, 'PPI::Document' );
-my $semi = $Document->find_first('Token::Structure');
-isa_ok( $semi, 'PPI::Token::Structure' );
-is( $semi->content, ';', 'Got expected token' );
-my $foo = PPI::Token::Word->new('foo');
-isa_ok( $foo, 'PPI::Token::Word' );
-is( $foo->content, 'foo', 'Created Word token' );
-$semi->insert_before( $foo );
-is( $Document->serialize, "print 'Hello World'foo;",
-	'insert_before actually inserts' );
-
-=end testing
+or C<undef> if you do not provide a C<PPI::Element> object as a parameter.
 
 =cut
 
@@ -526,39 +531,7 @@ In future, this method may be enhanced to allow the insertion of multiple
 Elements, inline-parsed code strings or L<PPI::Document::Fragment> objects.
 
 Returns true if the Element was inserted, false if it can not be inserted,
-or C<undef> if you do not provide a L<PPI::Element> object as a parameter.
-
-=begin testing __insert_after 6
-
-my $Document = PPI::Document->new( \"print 'Hello World';" );
-isa_ok( $Document, 'PPI::Document' );
-my $string = $Document->find_first('Token::Quote');
-isa_ok( $string, 'PPI::Token::Quote' );
-is( $string->content, "'Hello World'", 'Got expected token' );
-my $foo = PPI::Token::Word->new('foo');
-isa_ok( $foo, 'PPI::Token::Word' );
-is( $foo->content, 'foo', 'Created Word token' );
-$string->__insert_after( $foo );
-is( $Document->serialize, "print 'Hello World'foo;",
-	'__insert_after actually inserts' );
-
-=end testing
-
-=begin testing insert_after after __insert_after 6
-
-my $Document = PPI::Document->new( \"print 'Hello World';" );
-isa_ok( $Document, 'PPI::Document' );
-my $string = $Document->find_first('Token::Quote');
-isa_ok( $string, 'PPI::Token::Quote' );
-is( $string->content, "'Hello World'", 'Got expected token' );
-my $foo = PPI::Token::Word->new('foo');
-isa_ok( $foo, 'PPI::Token::Word' );
-is( $foo->content, 'foo', 'Created Word token' );
-$string->insert_after( $foo );
-is( $Document->serialize, "print 'Hello World'foo;",
-	'insert_after actually inserts' );
-
-=end testing
+or C<undef> if you do not provide a C<PPI::Element> object as a parameter.
 
 =cut
 
@@ -589,7 +562,7 @@ sub remove {
 
 =head2 delete
 
-For a given C<PPI::Element>, the C<remove> method will remove it from its
+For a given C<PPI::Element>, the C<delete> method will remove it from its
 parent, immediately deleting the C<Element> and all of its children (if it
 has any).
 
@@ -620,7 +593,7 @@ one being replaced.
 
 sub replace {
 	my $self    = ref $_[0] ? shift : return undef;
-	my $Element = _INSTANCE(shift, ref $self) or return undef;
+	_INSTANCE(shift, ref $self) or return undef;
 	die "The ->replace method has not yet been implemented";
 }
 
@@ -633,20 +606,141 @@ indexed the Element locations using C<PPI::Document::index_locations>, the
 C<location> method will return the location of the first character of the
 Element within the Document.
 
-Returns the location as a reference to a three-element array in the form
-C<[ $line, $rowchar, $col ]>. The values are in a human format, with the
-first character of the file located at C<[ 1, 1, 1 ]>. 
+Returns the location as a reference to a five-element array in the form C<[
+$line, $rowchar, $col, $logical_line, $logical_file_name ]>. The values are in
+a human format, with the first character of the file located at C<[ 1, 1, 1, ?,
+'something' ]>.
 
 The second and third numbers are similar, except that the second is the
 literal horizontal character, and the third is the visual column, taking
-into account tabbing.
+into account tabbing (see L<PPI::Document/"tab_width [ $width ]">).
 
-Returns C<undef> on error, or if the L<PPI::Document> object has not been indexed.
+The fourth number is the line number, taking into account any C<#line>
+directives.  The fifth element is the name of the file that the element was
+found in, if available, taking into account any C<#line> directives.
+
+Returns C<undef> on error, or if the L<PPI::Document> object has not been
+indexed.
 
 =cut
 
 sub location {
 	my $self = shift;
+
+	$self->_ensure_location_present or return undef;
+
+	# Return a copy, not the original
+	return [ @{$self->{_location}} ];
+}
+
+=pod
+
+=head2 line_number
+
+If the Element exists within a L<PPI::Document> that has indexed the Element
+locations using C<PPI::Document::index_locations>, the C<line_number> method
+will return the line number of the first character of the Element within the
+Document.
+
+Returns C<undef> on error, or if the L<PPI::Document> object has not been
+indexed.
+
+=cut
+
+sub line_number {
+	my $self = shift;
+
+	my $location = $self->location() or return undef;
+	return $location->[0];
+}
+
+=pod
+
+=head2 column_number
+
+If the Element exists within a L<PPI::Document> that has indexed the Element
+locations using C<PPI::Document::index_locations>, the C<column_number> method
+will return the column number of the first character of the Element within the
+Document.
+
+Returns C<undef> on error, or if the L<PPI::Document> object has not been
+indexed.
+
+=cut
+
+sub column_number {
+	my $self = shift;
+
+	my $location = $self->location() or return undef;
+	return $location->[1];
+}
+
+=pod
+
+=head2 visual_column_number
+
+If the Element exists within a L<PPI::Document> that has indexed the Element
+locations using C<PPI::Document::index_locations>, the C<visual_column_number>
+method will return the visual column number of the first character of the
+Element within the Document, according to the value of
+L<PPI::Document/"tab_width [ $width ]">.
+
+Returns C<undef> on error, or if the L<PPI::Document> object has not been
+indexed.
+
+=cut
+
+sub visual_column_number {
+	my $self = shift;
+
+	my $location = $self->location() or return undef;
+	return $location->[2];
+}
+
+=pod
+
+=head2 logical_line_number
+
+If the Element exists within a L<PPI::Document> that has indexed the Element
+locations using C<PPI::Document::index_locations>, the C<logical_line_number>
+method will return the line number of the first character of the Element within
+the Document, taking into account any C<#line> directives.
+
+Returns C<undef> on error, or if the L<PPI::Document> object has not been
+indexed.
+
+=cut
+
+sub logical_line_number {
+	my $self = shift;
+
+	return $self->location()->[3];
+}
+
+=pod
+
+=head2 logical_filename
+
+If the Element exists within a L<PPI::Document> that has indexed the Element
+locations using C<PPI::Document::index_locations>, the C<logical_filename>
+method will return the logical file name containing the first character of the
+Element within the Document, taking into account any C<#line> directives.
+
+Returns C<undef> on error, or if the L<PPI::Document> object has not been
+indexed.
+
+=cut
+
+sub logical_filename {
+	my $self = shift;
+
+	my $location = $self->location() or return undef;
+	return $location->[4];
+}
+
+sub _ensure_location_present {
+	my $self = shift;
+
 	unless ( exists $self->{_location} ) {
 		# Are we inside a normal document?
 		my $Document = $self->document or return undef;
@@ -666,8 +760,7 @@ sub location {
 		}
 	}
 
-	# Return a copy, not the original
-	return [ @{$self->{_location}} ];
+	return 1;
 }
 
 # Although flush_locations is only publically a Document-level method,
@@ -691,7 +784,7 @@ sub _flush_locations {
 			return 1 unless $Token->{_location};
 			next unless refaddr($Token) == refaddr($start);
 
-			# Found the start. Flush it's location
+			# Found the start. Flush its location
 			delete $$Token->{_location};
 			last;
 		}
@@ -785,7 +878,7 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2008 Adam Kennedy.
+Copyright 2001 - 2011 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
