@@ -12,7 +12,7 @@ PPI::Statement::End - Content after the __END__ of a module
   
   __END__
   
-  This is part of an PPI::Statement::End statement
+  This is part of a PPI::Statement::End statement
   
   =pod
   
@@ -45,12 +45,14 @@ provided by L<PPI::Statement>, L<PPI::Node> and L<PPI::Element>.
 =cut
 
 use strict;
-use base 'PPI::Statement';
+use PPI::Statement ();
 
-use vars qw{$VERSION};
-BEGIN {
-	$VERSION = '1.203';
-}
+our $VERSION = '1.271'; # VERSION
+
+our @ISA = "PPI::Statement";
+
+# Once we have an __END__ we're done
+sub _complete () { 1 }
 
 1;
 
@@ -66,7 +68,7 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2008 Adam Kennedy.
+Copyright 2001 - 2011 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
