@@ -23,7 +23,7 @@ type should actually exist in the tree.
 
 =head2 Elements vs Children
 
-A B<PPI::Structure> has an unusual existance. Unlike a L<PPI::Document>
+A B<PPI::Structure> has an unusual existence. Unlike a L<PPI::Document>
 or L<PPI::Statement>, which both simply contain other elements, a
 structure B<both> contains and consists of content.
 
@@ -37,19 +37,27 @@ end, the -E<gt>children method explicitly will B<not> return the brace.
 =head1 STRUCTURE CLASSES
 
 Excluding the transient L<PPI::Structure::Unknown> that exists briefly
-inside the parser, there are six types of structure.
+inside the parser, there are eight types of structure.
 
 =head2 L<PPI::Structure::List>
 
 This covers all round braces used for function arguments, in C<foreach>
 loops, literal lists, and braces used for precedence-ordering purposes.
 
-=head2 L<PPI::Structure::ForLoop>
+=head2 L<PPI::Structure::For>
 
 Although B<not> used for the C<foreach> loop list, this B<is> used for
-the special case of the round-brace three-part semicolon-seperated C<for>
+the special case of the round-brace three-part semicolon-separated C<for>
 loop expression (the traditional C style for loop).
 
+=head2 L<PPI::Structure::Given>
+
+This is for the expression being matched in switch statements.
+
+=head2 L<PPI::Structure::When>
+
+This is for the matching expression in "when" statements.
+
 =head2 L<PPI::Structure::Condition>
 
 This round-brace structure covers boolean conditional braces, such as
@@ -81,23 +89,25 @@ of the methods that are subclass-specific.
 =cut
 
 use strict;
-use base 'PPI::Node';
-use Scalar::Util                'refaddr';
-use Params::Util                '_INSTANCE';
+use Scalar::Util   ();
+use Params::Util   qw{_INSTANCE};
+use PPI::Node      ();
+use PPI::Exception ();
+use PPI::Singletons '%_PARENT';
 
-use vars qw{$VERSION *_PARENT};
-BEGIN {
-	$VERSION = '1.203';
-	*_PARENT = *PPI::Element::_PARENT;
-}
+our $VERSION = '1.271'; # VERSION
+
+our @ISA = "PPI::Node";
 
 use PPI::Structure::Block       ();
 use PPI::Structure::Condition   ();
 use PPI::Structure::Constructor ();
-use PPI::Structure::ForLoop     ();
+use PPI::Structure::For         ();
+use PPI::Structure::Given       ();
 use PPI::Structure::List        ();
 use PPI::Structure::Subscript   ();
 use PPI::Structure::Unknown     ();
+use PPI::Structure::When        ();
 
 
 
@@ -118,29 +128,12 @@ sub new {
 
 	# Set the start braces parent link
 	Scalar::Util::weaken(
-		$_PARENT{refaddr $Token} = $self
-		);
+		$_PARENT{Scalar::Util::refaddr $Token} = $self
+	);
 
 	$self;
 }
 
-# Hacky method to let the Lexer set the finish token, so it doesn't
-# have to import %PPI::Element::_PARENT itself.
-sub _set_finish {
-	my $self  = shift;
-
-	# Check the Token
-	my $Token = ($_[0] and $_[0]->isa('PPI::Token::Structure')) ? shift : return undef;
-	$Token->parent and return undef; # Must be a detached token
-	($self->start->__LEXER__opposite eq $Token->content) or return undef; # ... that matches the opening token
-
-	# Set the token
-	$self->{finish} = $Token;
-	$_PARENT{refaddr $Token} = $self;
-
-	1;
-}
-
 
 
 
@@ -178,7 +171,7 @@ The C<finish> method returns the finish brace for the structure (i.e. the
 closing brace).
 
 Returns the brace as a L<PPI::Token::Structure> or C<undef> if the
-structure does not have a starting brace. This can be quite common if
+structure does not have a finishing brace. This can be quite common if
 the document is not complete (for example, from an editor where the user
 may be halfway through typeing a subroutine).
 
@@ -190,16 +183,39 @@ sub finish { $_[0]->{finish} }
 
 =head2 braces
 
-The C<braces> method is a utility method which returns the brace type.
+The C<braces> method is a utility method which returns the brace type,
+regardless of whether both or just one of the braces is defined.
 
-Returns on of the three strings C<'[]'>, C<'{}'>, or C<'()'>, or C<undef>
+Returns one of the three strings C<'[]'>, C<'{}'>, or C<'()'>, or C<undef>
 on error (primarily not having a start brace, as mentioned above).
 
 =cut
 
 sub braces {
 	my $self = $_[0]->{start} ? shift : return undef;
-	return { '[' => '[]', '(' => '()', '{' => '{}' }->{ $self->{start}->{content} };
+	return {
+		'[' => '[]',
+		'(' => '()',
+		'{' => '{}',
+	}->{ $self->{start}->{content} };
+}
+
+=pod
+
+=head1 complete
+
+The C<complete> method is a convenience method that returns true if
+the both braces are defined for the structure, or false if only one
+brace is defined.
+
+Unlike the top level C<complete> method which checks for completeness
+in depth, the structure complete method ONLY confirms completeness
+for the braces, and does not recurse downwards.
+
+=cut
+
+sub complete {
+	!! ($_[0]->{start} and $_[0]->{finish});
 }
 
 
@@ -239,7 +255,6 @@ sub last_element {
 	$_[0]->{finish} or $_[0]->{children}->[-1] or $_[0]->{start};
 }
 
-
 # Location is same as the start token, if any
 sub location {
 	my $self  = shift;
@@ -249,6 +264,8 @@ sub location {
 
 
 
+
+
 #####################################################################
 # PPI::Element overloaded methods
 
@@ -319,7 +336,7 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2008 Adam Kennedy.
+Copyright 2001 - 2011 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
