@@ -28,17 +28,14 @@ reference of C<HASH> reference constructors.
 C<PPI::Structure::Constructor> has no methods beyond those provided by
 the standard L<PPI::Structure>, L<PPI::Node> and L<PPI::Element> methods.
 
-Got any ideas for methods? Submit a report to rt.cpan.org!
-
 =cut
 
 use strict;
-use base 'PPI::Structure';
+use PPI::Structure ();
 
-use vars qw{$VERSION};
-BEGIN {
-	$VERSION = '1.118';
-}
+our $VERSION = '1.271'; # VERSION
+
+our @ISA = "PPI::Structure";
 
 1;
 
@@ -54,7 +51,7 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2006 Adam Kennedy.
+Copyright 2001 - 2011 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
