@@ -22,17 +22,14 @@ last index of an array, such as C<$#array>.
 There are no additional methods beyond those provided by the parent
 L<PPI::Token> and L<PPI::Element> classes.
 
-Got any ideas for methods? Submit a report to rt.cpan.org!
-
 =cut
 
 use strict;
-use base 'PPI::Token';
+use PPI::Token ();
 
-use vars qw{$VERSION};
-BEGIN {
-	$VERSION = '1.118';
-}
+our $VERSION = '1.271'; # VERSION
+
+our @ISA = "PPI::Token";
 
 
 
@@ -45,8 +42,8 @@ sub __TOKENIZER__on_char {
 	my $t = $_[1];
 
 	# Suck in till the end of the arrayindex
-	my $line = substr( $t->{line}, $t->{line_cursor} );
-	if ( $line =~ /^([\w:']+)/ ) {
+	pos $t->{line} = $t->{line_cursor};
+	if ( $t->{line} =~ m/\G([\w:']+)/gc ) {
 		$t->{token}->{content} .= $1;
 		$t->{line_cursor} += length $1;
 	}
@@ -69,7 +66,7 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2006 Adam Kennedy.
+Copyright 2001 - 2011 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
