@@ -19,7 +19,7 @@ The "dashed bareword" token represents literal values like C<-foo>.
 NOTE: this class is currently unused.  All tokens that should be
 PPI::Token::DashedWords are just normal PPI::Token::Word instead.
 That actually makes sense, since there really is nothing special about
-this class except that dashed words cannot subroutine names or
+this class except that dashed words cannot be subroutine names or
 keywords.  As such, this class may be removed from PPI in the future.
 
 =head1 METHODS
@@ -27,38 +27,19 @@ keywords.  As such, this class may be removed from PPI in the future.
 =cut
 
 use strict;
-use base 'PPI::Token';
+use PPI::Token ();
 
-use vars qw{$VERSION};
-BEGIN {
-	$VERSION = '1.203';
-}
+our $VERSION = '1.271'; # VERSION
+
+our @ISA = "PPI::Token";
+
+=pod
 
 =head2 literal
 
 Returns the value of the dashed word as a string.  This differs from
 C<content> because C<-Foo'Bar> expands to C<-Foo::Bar>.
 
-=begin testing literal 9
-
-my @pairs = (
-	"-foo",        '-foo',
-	"-Foo::Bar",   '-Foo::Bar',
-	"-Foo'Bar",    '-Foo::Bar',
-);
-while ( @pairs ) {
-	my $from  = shift @pairs;
-	my $to    = shift @pairs;
-	my $doc   = PPI::Document->new( \"(<$from => 1);" );
-	isa_ok( $doc, 'PPI::Document' );
-	my $word = $doc->find_first('Token::DashedWord');
-	local $TODO = 'PPI::Token::DashedWord is currently deactivated';
-	isa_ok( $word, 'PPI::Token::DashedWord' );
-	is( $word && $word->literal, $to, "The source $from becomes $to ok" );
-}
-
-=end testing 
-
 =cut
 
 *literal = *PPI::Token::Word::literal;
@@ -72,8 +53,8 @@ sub __TOKENIZER__on_char {
 	my $t = $_[1];
 
 	# Suck to the end of the dashed bareword
-	my $line = substr( $t->{line}, $t->{line_cursor} );
-	if ( $line =~ /^(\w+)/ ) {
+	pos $t->{line} = $t->{line_cursor};
+	if ( $t->{line} =~ m/\G(\w+)/gc ) {
 		$t->{token}->{content} .= $1;
 		$t->{line_cursor} += length $1;
 	}
@@ -104,7 +85,7 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2008 Adam Kennedy.
+Copyright 2001 - 2011 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
