@@ -30,12 +30,13 @@ in the various types that Perl supports.
 =cut
 
 use strict;
-use base 'PPI::Token';
+use PPI::Token ();
 
-use vars qw{$VERSION};
-BEGIN {
-	$VERSION = '1.203';
-}
+our $VERSION = '1.271'; # VERSION
+
+our @ISA = "PPI::Token";
+
+=pod
 
 =head2 base
 
@@ -44,9 +45,9 @@ This is 10 for decimal, 16 for hexadecimal, 2 for binary, etc.
 
 =cut
 
-sub base {
-	return 10;
-}
+sub base() { 10 }
+
+=pod
 
 =head2 literal
 
@@ -55,19 +56,22 @@ Return the numeric value of this token.
 =cut
 
 sub literal {
-	my $self = shift;
-	return 0+$self->_literal;
+	return 0 + $_[0]->_literal;
 }
 
 sub _literal {
 	# De-sugar the string representation
-	my $self = shift;
-	my $str = $self->content;
-	$str =~ s/^\+//;
-	$str =~ s/_//g;
-	return $str;
+	my $self   = shift;
+	my $string = $self->content;
+	$string =~ s/^\+//;
+	$string =~ s/_//g;
+	return $string;
 }
 
+
+
+
+
 #####################################################################
 # Tokenizer Methods
 
@@ -84,10 +88,10 @@ sub __TOKENIZER__on_char {
 	my $token = $t->{token};
 	if ( $token->{content} =~ /^-?0_*$/ ) {
 		# This could be special
-		if ( $char eq 'x' ) {
+		if ( $char eq 'x' || $char eq 'X' ) {
 			$t->{class} = $t->{token}->set_class( 'Number::Hex' );
 			return 1;
-		} elsif ( $char eq 'b' ) {
+		} elsif ( $char eq 'b' || $char eq 'B' ) {
 			$t->{class} = $t->{token}->set_class( 'Number::Binary' );
 			return 1;
 		} elsif ( $char =~ /\d/ ) {
@@ -131,7 +135,7 @@ Perl, but is allowed in PPI:
 
 =head1 TO DO
 
-- Treak v-strings as binary strings or barewords, not as "base-256"
+- Treat v-strings as binary strings or barewords, not as "base-256"
   numbers
 
 - Break out decimal integers into their own subclass?
@@ -148,7 +152,7 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2008 Adam Kennedy.
+Copyright 2001 - 2011 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
