@@ -36,14 +36,12 @@ use strict;
 use PPI::Token::Quote ();
 use PPI::Token::_QuoteEngine::Simple ();
 
-use vars qw{$VERSION @ISA};
-BEGIN {
-	$VERSION = '1.220';
-	@ISA     = qw{
-		PPI::Token::_QuoteEngine::Simple
-		PPI::Token::Quote
-	};
-}
+our $VERSION = '1.271'; # VERSION
+
+our @ISA = qw{
+	PPI::Token::_QuoteEngine::Simple
+	PPI::Token::Quote
+};
 
 
 
