@@ -33,12 +33,11 @@ parent classes.
 =cut
 
 use strict;
-use base 'PPI::Token::Word';
+use PPI::Token::Word ();
 
-use vars qw{$VERSION};
-BEGIN {
-	$VERSION = '1.203';
-}
+our $VERSION = '1.271'; # VERSION
+
+our @ISA = "PPI::Token::Word";
 
 1;
 
@@ -54,7 +53,7 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2008 Adam Kennedy.
+Copyright 2001 - 2011 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
